import os
from typing import List, Dict
from openai import OpenAI
from groq import Groq

class techvai_chat:
    """
    A chat interface for interacting with LLM providers via the client.
    """

    def __init__(self, client):
        """
        Initialize the chat interface.

        Args:
            client: The provider-specific API client instance.
        """
        self.client = client
    def generate_text(self, 
             messages: List[Dict[str, str]], 
             model: str, 
             temperature: float = 0.6, 
             max_tokens: int = 1024, 
             top_p: float = 0.9, 
             stream: bool = False):
        """
        Send a chat request to the LLM provider.

        Args:
            messages (list): List of message dictionaries in the format [{"role": "user", "content": "Hello"}].
            model (str): The model to use (must be specified by the user).
            temperature (float): Sampling temperature (default: 0.1).
            max_tokens (int): Maximum number of tokens to generate (default: 1024).
            top_p (float): Top-p sampling parameter (default: 0.9).
            stream (bool): Whether to stream the response (default: False).

        Returns:
            The response from the LLM provider.
        """
        if isinstance(self.client, OpenAI):
            response = self.client.chat.completions.create(
                model=model,
                messages=messages,
                temperature=temperature,
                max_tokens=max_tokens,
                top_p=top_p,
                stream=stream,
            )
        elif isinstance(self.client, Groq):
            response = self.client.chat(
                model=model,
                messages=messages,
                temperature=temperature,
                max_tokens=max_tokens,
                top_p=top_p,
                stream=stream,
            )
        else:
            raise ValueError("Unsupported client type.")

        return response
